@@ -140,7 +140,7 @@ void GroupView::onItemClicked(const QModelIndex &index)
 {
     Group *g = model->groupForIndex(index);
     if (g)
-        currentGroupChanged(g);
+        Q_EMIT currentGroupChanged(g);
 }
 
 void GroupView::editGroupPolicy()
@@ -189,6 +189,8 @@ void GroupView::openInNewTab()
 {
     Group *g = model->groupForIndex(selectionModel()->currentIndex());
     if (g)
-        openTab(g);
+        Q_EMIT openTab(g);
 }
 }
+
+#include "moc_groupview.cpp"
