@@ -121,7 +121,7 @@ void ScanExtender::cancelPressed()
 
 void ScanExtender::closeRequested()
 {
-    closeRequest(this);
+    Q_EMIT closeRequest(this);
 }
 
 bool ScanExtender::similar(Extender *ext) const
@@ -130,3 +130,5 @@ bool ScanExtender::similar(Extender *ext) const
 }
 
 }
+
+#include "moc_scanextender.cpp"
